<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Reiškinio klaida</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Tamsi tema</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Paprasta veiksena</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Mokslinė veiksena</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin skaičiuotuvas</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin skaičiuotuvas yra paprastas ir lengvas naudoti darbalaukio skaičiuotuvas. Jis palaiko sudėtį, atimtį, daugybą ir dalybą.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Reiškinio klaida</translation>
    </message>
</context>
</TS>